==> freemedforms-project_0.7.6.orig.tar.gz: freemedforms-0.7.6/libs/translationutils/trans_countries.h <==
/***************************************************************************
 *  The FreeMedForms project is a set of free, open source medical         *
 *  applications.                                                          *
 *  (C) 2008-2012 by Eric MAEKER, MD (France) <eric.maeker@gmail.com>      *
 *  All rights reserved.                                                   *
 *                                                                         *
 *  This program is free software: you can redistribute it and/or modify   *
 *  it under the terms of the GNU General Public License as published by   *
 *  the Free Software Foundation, either version 3 of the License, or      *
 *  (at your option) any later version.                                    *
 *                                                                         *
 *  This program is distributed in the hope that it will be useful,        *
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
 *  GNU General Public License for more details.                           *
 *                                                                         *
 *  You should have received a copy of the GNU General Public License      *
 *  along with this program (COPYING.FREEMEDFORMS file).                   *
 *  If not, see <http://www.gnu.org/licenses/>.                            *
 ***************************************************************************/
/***************************************************************************
 *   Main developers : Eric MAEKER, <eric.maeker@gmail.com>                *
 *   Contributors :                                                        *
 *       NAME <MAIL@ADDRESS.COM>                                           *
 ***************************************************************************/
#ifndef CONSTANTTRANSLATIONS_COUNTRIES_H
#define CONSTANTTRANSLATIONS_COUNTRIES_H

#include <QCoreApplication>

namespace Trans {
namespace Constants {

// Countries
const char* const COUNTRY_FRANCE      = QT_TRANSLATE_NOOP( "tkConstants", "France" );
const char* const COUNTRY_GERMANY     = QT_TRANSLATE_NOOP( "tkConstants", "Germany" );
const char* const COUNTRY_CANADA      = QT_TRANSLATE_NOOP( "tkConstants", "Canada" );
const char* const COUNTRY_AUSTRIA     = QT_TRANSLATE_NOOP( "tkConstants", "Austria" );

} // end Constants
} // end TranslationUtils

#endif // CONSTANTTRANSLATIONS_COUNTRIES_H

==> freemedforms-project_0.9.0.orig.tar.gz: freemedforms-0.9.0/libs/translationutils/trans_countries.h <==
/***************************************************************************
 *  The FreeMedForms project is a set of free, open source medical         *
 *  applications.                                                          *
 *  (C) 2008-2013 by Eric MAEKER, MD (France) <eric.maeker@gmail.com>      *
 *  All rights reserved.                                                   *
 *                                                                         *
 *  This program is free software: you can redistribute it and/or modify   *
 *  it under the terms of the GNU General Public License as published by   *
 *  the Free Software Foundation, either version 3 of the License, or      *
 *  (at your option) any later version.                                    *
 *                                                                         *
 *  This program is distributed in the hope that it will be useful,        *
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
 *  GNU General Public License for more details.                           *
 *                                                                         *
 *  You should have received a copy of the GNU General Public License      *
 *  along with this program (COPYING.FREEMEDFORMS file).                   *
 *  If not, see <http://www.gnu.org/licenses/>.                            *
 ***************************************************************************/
/***************************************************************************
 *  Main developer: Eric MAEKER, <eric.maeker@gmail.com>                   *
 *  Contributors:                                                          *
 *       NAME <MAIL@ADDRESS.COM>                                           *
 ***************************************************************************/
#ifndef CONSTANTTRANSLATIONS_COUNTRIES_H
#define CONSTANTTRANSLATIONS_COUNTRIES_H

#include <qglobal.h>

namespace Trans {
namespace Constants {

// Countries
const char* const COUNTRY_FRANCE      = QT_TRANSLATE_NOOP( "tkConstants", "France" );
const char* const COUNTRY_GERMANY     = QT_TRANSLATE_NOOP( "tkConstants", "Germany" );
const char* const COUNTRY_CANADA      = QT_TRANSLATE_NOOP( "tkConstants", "Canada" );
const char* const COUNTRY_AUSTRIA     = QT_TRANSLATE_NOOP( "tkConstants", "Austria" );
const char* const COUNTRY_USA         = QT_TRANSLATE_NOOP( "tkConstants", "USA" );
const char* const COUNTRY_SOUTHAFRICA = QT_TRANSLATE_NOOP( "tkConstants", "South Africa" );
const char* const COUNTRY_BELGIUM     = QT_TRANSLATE_NOOP( "tkConstants", "Belgium" );
const char* const COUNTRY_PORTUGAL    = QT_TRANSLATE_NOOP( "tkConstants", "Portugal" );
const char* const COUNTRY_BRASIL      = QT_TRANSLATE_NOOP( "tkConstants", "Brasil" );

} // end Constants
} // end TranslationUtils

#endif // CONSTANTTRANSLATIONS_COUNTRIES_H
